@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #-------------------------------------------------------------------------------
-# $Id: create_instance.py 2136 2012-11-22 17:29:40Z meissls $
+# $Id: create_instance.py 2203 2012-12-27 16:24:46Z meissls $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Fabian Schindler <fabian.schindler@eox.at>
@@ -143,6 +143,12 @@ class Command(EOxServerAdminCommand):
         
         shutil.copy(os.path.join(src_conf_dir, "TEMPLATE_template.map"),
                     os.path.join(dst_conf_dir, "template.map"))
+        shutil.copy(os.path.join(src_conf_dir, "TEMPLATE_outline_template_dataset.html"),
+                    os.path.join(dst_conf_dir, "outline_template_dataset.html"))
+        shutil.copy(os.path.join(src_conf_dir, "TEMPLATE_outline_template_footer.html"),
+                    os.path.join(dst_conf_dir, "outline_template_footer.html"))
+        shutil.copy(os.path.join(src_conf_dir, "TEMPLATE_outline_template_header.html"),
+                    os.path.join(dst_conf_dir, "outline_template_header.html"))
         
         shutil.copy(os.path.join(src_conf_dir, "init_spatialite-2.3.sql"),
                     os.path.join(dst_data_dir, "init_spatialite-2.3.sql"))
