@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: admin.py 1594 2012-03-29 13:37:43Z krauses $
+# $Id: admin.py 1937 2012-08-07 13:16:47Z schindlerf $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -168,7 +168,7 @@ class RectifiedDatasetAdmin(ConfirmationAdmin):
         self.message_user(request, "%s successfully deleted." % message_bit)
     really_delete_selected.short_description = "Delete selected Dataset entries"
 
-    def change_view(self, request, object_id, extra_context=None):
+    def change_view(self, request, object_id, *args, **kwargs):
         obj = self.get_object(request, object_id)
         diff = self.get_changes(request, object_id)
         old_automatic, new_automatic = diff.get('automatic', (False, False))
@@ -177,7 +177,7 @@ class RectifiedDatasetAdmin(ConfirmationAdmin):
             messages.warning(request, "This rectified dataset cannot be changed "
                              "because it is marked as 'automatic'.")
             
-        return super(RectifiedDatasetAdmin, self).change_view(request, object_id, extra_context)
+        return super(RectifiedDatasetAdmin, self).change_view(request, object_id, *args, **kwargs)
 
     def get_readonly_fields(self, request, obj=None):
         """
@@ -236,7 +236,7 @@ class ReferenceableDatasetAdmin(ConfirmationAdmin):
         self.message_user(request, "%s successfully deleted." % message_bit)
     really_delete_selected.short_description = "Delete selected Dataset entries"
 
-    def change_view(self, request, object_id, extra_context=None):
+    def change_view(self, request, object_id, *args, **kwargs):
         obj = self.get_object(request, object_id)
         diff = self.get_changes(request, object_id)
         old_automatic, new_automatic = diff.get('automatic', (False, False))
@@ -245,7 +245,7 @@ class ReferenceableDatasetAdmin(ConfirmationAdmin):
             messages.warning(request, "This referenceable dataset cannot be changed "
                              "because it is marked as 'automatic'.")
             
-        return super(ReferenceableDatasetAdmin, self).change_view(request, object_id, extra_context)
+        return super(ReferenceableDatasetAdmin, self).change_view(request, object_id, *args, **kwargs)
 
     def get_readonly_fields(self, request, obj=None):
         """
@@ -339,9 +339,9 @@ class AbstractContainerAdmin(admin.ModelAdmin):
             messages.error(request, "Could not create %s" % self.model._meta.verbose_name)
             return HttpResponseRedirect("..")
     
-    def change_view(self, request, object_id, extra_context=None):
+    def change_view(self, request, object_id, *args, **kwargs):
         try:
-            ret = super(AbstractContainerAdmin, self).change_view(request, object_id, extra_context)
+            ret = super(AbstractContainerAdmin, self).change_view(request, object_id, *args, **kwargs)
             self.try_synchronize()
             return ret
         except:
@@ -500,7 +500,7 @@ class EOMetadataAdmin(admin.GeoModelAdmin):
         
         super(EOMetadataAdmin, self).save_formset(request, form, formset, change)
     
-    def change_view(self, request, object_id, extra_context=None):
+    def change_view(self, request, object_id, *args, **kwarg):
         obj = self.get_object(request, unquote(object_id))
         try:
             if obj.rectifieddatasetrecord_set.automatic:
@@ -508,7 +508,7 @@ class EOMetadataAdmin(admin.GeoModelAdmin):
                                  "the associated dataset is marked as 'automatic'.")
         except ObjectDoesNotExist:
             pass
-        return super(EOMetadataAdmin, self).change_view(request, object_id, extra_context)
+        return super(EOMetadataAdmin, self).change_view(request, object_id, *args, **kwarg)
     
     def get_readonly_fields(self, request, obj=None):
         try:
