@@ -1,9 +1,10 @@
 #-------------------------------------------------------------------------------
-# $Id: encoders.py 1571 2012-03-23 14:07:54Z meissls $
+# $Id: encoders.py 1885 2012-07-31 09:29:38Z meissls $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
 #          Stephan Meissl <stephan.meissl@eox.at>
+#          Martin Paces <martin.paces@eox.at>
 #
 #-------------------------------------------------------------------------------
 # Copyright (C) 2011 EOX IT Services GmbH
@@ -381,6 +382,9 @@ class WCS20Encoder(CoverageGML10Encoder):
         })
         return ns_dict
     
+    def encodeExtension(self):
+        return self._makeElement("wcs", "Extension", [])
+    
     def encodeCoverageDescription(self, coverage):
         return self._makeElement("wcs", "CoverageDescription", [
             ("@gml", "id", self._getGMLId(coverage.getCoverageId())),
@@ -390,6 +394,7 @@ class WCS20Encoder(CoverageGML10Encoder):
             (self.encodeRangeType(coverage),),
             ("wcs", "ServiceParameters", [
                 ("wcs", "CoverageSubtype", coverage.getCoverageSubtype()),
+                ("wcs", "nativeFormat", "image/tiff")
             ])
         ])
     
@@ -398,8 +403,9 @@ class WCS20Encoder(CoverageGML10Encoder):
             sub_nodes = [("@xsi", "schemaLocation", "http://www.opengis.net/wcseo/1.0 http://schemas.opengis.net/wcseo/1.0/wcsEOAll.xsd")]
         else:
             sub_nodes = []
-            
-        sub_nodes.extend([(self.encodeCoverageDescription(coverage),) for coverage in coverages])
+        
+        if coverages is not None and len(coverages) != 0:
+          sub_nodes.extend([(self.encodeCoverageDescription(coverage),) for coverage in coverages])
         return self._makeElement("wcs", "CoverageDescriptions", sub_nodes)
 
 class WCS20EOAPEncoder(WCS20Encoder):
@@ -478,15 +484,19 @@ class WCS20EOAPEncoder(WCS20Encoder):
         
         if lineage is None:
             return self._makeElement("gmlcov", "metadata", [
-                ("wcseo", "EOMetadata", [
-                    (earth_observation,),
+                ("gmlcov", "Extension", [
+                    ("wcseo", "EOMetadata", [
+                        (earth_observation,),
+                    ]),
                 ]),
             ])
         else:
             return self._makeElement("gmlcov", "metadata", [
-                ("wcseo", "EOMetadata", [
-                    (earth_observation,),
-                    (lineage,)
+                ("gmlcov", "Extension", [
+                    ("wcseo", "EOMetadata", [
+                        (earth_observation,),
+                        (lineage,)
+                    ]),
                 ]),
             ])
 
@@ -513,10 +523,64 @@ class WCS20EOAPEncoder(WCS20Encoder):
             (self.encodeRangeType(coverage),),
             ("wcs", "ServiceParameters", [
                 ("wcs", "CoverageSubtype", coverage.getEOCoverageSubtype()),
+                ("wcs", "nativeFormat", "image/tiff")
             ])
         ])
         return self._makeElement("wcs", "CoverageDescription", sub_nodes)
     
+    def encodeRangeSet( self , reference , mimeType ) :
+
+        return self._makeElement("gml", "rangeSet", 
+            [( "gml","File" , 
+                [("gml","rangeParameters",
+                    [( "@xlink" , "arcrole" , "fileReference" ), 
+                     ( "@xlink" , "href" , reference ), 
+                     ( "@xlink" , "role" , mimeType ), 
+                    ]),
+                 ("gml","fileReference",reference), 
+                 ("gml","fileStructure",[]), 
+                 ("gml","mimeType",mimeType), 
+                ]),
+            ]) 
+
+    def encodeReferenceableDataset( self , coverage , reference , mimeType , is_root = False , subset = None ) : 
+
+        # handle subset 
+
+        if subset is None : 
+            # whole area - no subset 
+            domain = self.encodeDomainSet(coverage)
+            eomd   = self.encodeEOMetadata(coverage)
+            wgs84_extent = coverage.getWGS84Extent()
+
+        else : 
+        
+            # subset is given 
+            srid, size, extent, footprint = subset 
+
+            domain = self.encodeSubsetDomainSet(coverage, srid, size, extent)
+            eomd   = self.encodeEOMetadata(coverage, poly=footprint)
+
+            # get the WGS84 extent
+            poly = Polygon.from_bbox(extent)
+            poly.srid = srid
+            poly.transform(4326)
+            wgs84_extent = poly.extent
+
+        sub_nodes = []  
+
+        if is_root:
+            sub_nodes.append( ("@xsi", "schemaLocation", "http://www.opengis.net/wcseo/1.0 http://schemas.opengis.net/wcseo/1.0/wcsEOAll.xsd") )
+
+        sub_nodes.extend([
+            ("@gml", "id", self._getGMLId(coverage.getCoverageId())),
+            (self.encodeBoundedBy(*wgs84_extent),),(domain,),
+            (self.encodeRangeSet( reference , mimeType ),),
+            (self.encodeRangeType(coverage),),(eomd,),])
+
+        return self._makeElement("wcseo", "ReferenceableDataset", sub_nodes)
+
+
     def encodeSubsetCoverageDescription(self, coverage, srid, size, extent, footprint, is_root=False):
         poly = Polygon.from_bbox(extent)
         poly.srid = srid
@@ -558,9 +622,11 @@ class WCS20EOAPEncoder(WCS20Encoder):
         ])
 
     def encodeDatasetSeriesDescriptions(self, datasetseriess):
-        return self._makeElement("wcseo", "DatasetSeriesDescriptions", [
-            (self.encodeDatasetSeriesDescription(datasetseries),) for datasetseries in datasetseriess
-        ])
+        if datasetseriess is not None and len(datasetseriess) != 0:
+            sub_nodes = [(self.encodeDatasetSeriesDescription(datasetseries),) for datasetseries in datasetseriess]
+        else:
+            sub_nodes = []
+        return self._makeElement("wcseo", "DatasetSeriesDescriptions", sub_nodes)
         
     def encodeEOCoverageSetDescription(self, datasetseriess, coverages, numberMatched=None, numberReturned=None):
         if numberMatched is None:
