@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: owscommon.py 1118 2012-01-12 16:00:01Z meissls $
+# $Id: owscommon.py 2108 2012-11-18 23:08:58Z martin.paces $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -70,6 +70,14 @@ class OWSCommonHandler(BaseRequestHandler):
         req.setSchema(self.PARAM_SCHEMA)
         
         service = req.getParamValue("service")
+
+        # WMS hack - allowing WMS operation without service identifier 
+        if service is None:
+            op = req.getParamValue("operation")
+            if op and op.lower() in ( "getmap" , "getfeatureinfo" , "describelayer" , "getlegendgraphic" , "getstyles" ) : 
+                service = "WMS"
+        # WMS hack - the end 
+
         if service is None:
             raise InvalidRequestException(
                 "Mandatory 'service' parameter missing.",
