@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: testbase.py 1887 2012-07-31 11:37:48Z meissls $
+# $Id: testbase.py 2145 2012-11-27 22:25:20Z meissls $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -43,7 +43,7 @@ from django.db import connection
 from eoxserver.core.system import System
 from eoxserver.core.util.xmltools import XMLDecoder
 from eoxserver.testing.core import (
-    EOxServerTestCase, BASE_FIXTURES
+    EOxServerTestCase, EOxServerTransactionTestCase, BASE_FIXTURES
 )
 
 # THIS IS INTENTIONALLY DOUBLED DUE TO A BUG IN MIMETYPES!
@@ -72,7 +72,7 @@ def resolution_from_ds(ds):
 # Common classes
 #===============================================================================
 
-class OWSTestCase(EOxServerTestCase):
+class OWSMixIn(object):
     """ Main base class for testing the OWS interface
         of EOxServer.
     """
@@ -81,14 +81,14 @@ class OWSTestCase(EOxServerTestCase):
     requires_fixed_db = False
     
     def setUp(self):
-        super(OWSTestCase,self).setUp()
+        super(OWSMixIn,self).setUp()
         
         logging.info("Starting Test Case: %s" % self.__class__.__name__)
         
         if settings.DATABASES["default"]["NAME"] == ":memory:" and self.requires_fixed_db:
             self.skipTest("This test requires a file database; set 'TEST_NAME' "
                           "in your default database settings to enable this test.")
-        elif self.requires_fixed_db:
+        elif self.requires_fixed_db and settings.DATABASES["default"]["ENGINE"] == "django.contrib.gis.db.backends.spatialite":
             cursor = connection.cursor()
             cursor.execute("PRAGMA SYNCHRONOUS;")
 
@@ -173,8 +173,8 @@ class OWSTestCase(EOxServerTestCase):
             actual_response = Data
 
         if expected != actual_response:
-            if self.getFileExtension("raster") == "hdf":
-                self.skipTest("Skipping binary comparison for HDF file '%s'." % expected_path)
+            if self.getFileExtension("raster") in ("hdf", "nc"):
+                self.skipTest("Skipping binary comparison for HDF or NetCDF file '%s'." % expected_path)
             f = open(response_path, 'w')
             f.write(actual_response)
             f.close()
@@ -190,7 +190,14 @@ class OWSTestCase(EOxServerTestCase):
         logging.info("Checking HTTP Status ...")
         self.assertEqual(self.response.status_code, 200)
 
-class RasterTestCase(OWSTestCase):
+class OWSTestCase(OWSMixIn, EOxServerTestCase):
+    pass
+
+class OWSTransactionTestCase(OWSMixIn, EOxServerTransactionTestCase):
+    pass
+
+
+class RasterMixIn(object):
     """
     Base class for test cases that expect a raster as response.
     """
@@ -203,6 +210,12 @@ class RasterTestCase(OWSTestCase):
             self.skipTest("Binary raster comparison is explicitly disabled.")
         self._testBinaryComparison("raster")
 
+class RasterTestCase(RasterMixIn, OWSTestCase):
+    pass
+
+class RasterTransactionTestCase(RasterMixIn, OWSTransactionTestCase):
+    pass
+
 class GDALDatasetTestCase(RasterTestCase):
     """
     Extended RasterTestCases that open the result with GDAL and
@@ -325,6 +338,8 @@ class XMLTestCase(OWSTestCase):
         )
         
         for ns, location in zip(locations[::2], locations[1::2]):
+            if location == "../owsCoverages.xsd":
+                location = "http://schemas.opengis.net/wcs/1.1/wcsAll.xsd"
             etree.SubElement(schema_def, "import", attrib={
                     "namespace": ns,
                     "schemaLocation": location
@@ -368,12 +383,12 @@ class ExceptionTestCase(XMLTestCase):
         })
         self.assertEqual(decoder.getValue("exceptionCode"), self.getExpectedExceptionCode())      
 
-class HTMLTestCase(OWSTestCase):
+class HTMLTransactionTestCase(OWSTransactionTestCase):
     """
     HTML test cases expect to receive HTML text.
     """
     
-    def testBinaryComparisonRaster(self):
+    def testBinaryComparisonHTML(self):
         self._testBinaryComparison("html")
 
 class MultipartTestCase(XMLTestCase):
@@ -398,7 +413,7 @@ class MultipartTestCase(XMLTestCase):
         for part in response_msg.walk():
             if part['Content-type'] == "multipart/mixed; boundary=wcs":
                 continue
-            elif part['Content-type'] == "text/xml":
+            elif part['Content-type'] in ("text/xml", "application/gml+xml"):
                 # The filename depends on the actual time the request was 
                 # answered. It has to be explicitly unified.
                 tree = etree.fromstring(part.get_payload())
@@ -476,7 +491,9 @@ class WCSTransactionTestCase(XMLTestCase):
         logging.debug("WCSTransactionTestCase for ID: %s" % self.ID)
         
         if self.isAsync:
-            from eoxserver.resources.processes.tracker import *
+            from eoxserver.resources.processes.tracker import (
+                dequeueTask, TaskStatus, startTask, stopTaskSuccessIfNotFinished
+            )
 
             # get a pending task from the queue
             taskId = dequeueTask(1)[0]
@@ -789,10 +806,51 @@ class RasdamanTestCaseMixIn(object):
         super(RasdamanTestCaseMixIn, self).setUp()
     
 #===============================================================================
-# WMS 1.3 test classes
+# WMS test classes
 #===============================================================================
 
-class WMS13GetMapTestCase(RasterTestCase):
+class WMS11GetMapMixIn(object):
+    layers = []
+    styles = []
+    crs = "epsg:4326"
+    bbox = (0, 0, 1, 1)
+    width = 100
+    height = 100
+    frmt = "image/jpeg"
+    time = None
+    dim_band = None
+    
+    swap_axes = True
+    
+    httpHeaders = None
+    
+    def getFileExtension(self, part=None):
+        return mimetypes.guess_extension(self.frmt, False)[1:]
+    
+    def getRequest(self):
+        params = "service=WMS&request=GetMap&version=1.1.1&" \
+                 "layers=%s&styles=%s&srs=%s&bbox=%s&" \
+                 "width=%d&height=%d&format=%s" % (
+                     ",".join(self.layers), ",".join(self.styles), self.crs,
+                     ",".join(map(str, self.bbox)),
+                     self.width, self.height, self.frmt
+                 )
+        
+        if self.time:
+            params += "&time=%s" % self.time
+            
+        if self.dim_band:
+            params += "&dim_band=%s" % self.dim_band
+        
+        if self.httpHeaders is None:
+            return (params, "kvp")
+        else:
+            return (params, "kvp", self.httpHeaders)
+
+class WMS11GetMapTestCase(WMS11GetMapMixIn, RasterTestCase):
+    pass
+
+class WMS13GetMapMixIn(object):
     layers = []
     styles = []
     crs = "epsg:4326"
@@ -835,6 +893,12 @@ class WMS13GetMapTestCase(RasterTestCase):
         else:
             return (params, "kvp", self.httpHeaders)
 
+class WMS13GetMapTestCase(WMS13GetMapMixIn, RasterTestCase):
+    pass
+
+class WMS13GetMapTransactionTestCase(WMS13GetMapMixIn, RasterTransactionTestCase):
+    pass
+
 class WMS13ExceptionTestCase(ExceptionTestCase):
     def getExceptionCodeLocation(self):
         return "/{http://www.opengis.net/ogc}ServiceException/@code"
