@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: tests.py 1892 2012-07-31 13:10:42Z meissls $
+# $Id: tests.py 2145 2012-11-27 22:25:20Z meissls $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -34,6 +34,15 @@ import unittest
 
 from urllib import quote
 
+class EmptyRequestExceptionTestCase(eoxstest.ExceptionTestCase):
+    """This test shall check empty requests. A valid ows:ExceptionReport shall be returned"""
+    def getRequest(self):
+        params = ""
+        return (params, "kvp")
+
+    def getExpectedExceptionCode(self):
+        return "MissingParameterValue"
+
 #===============================================================================
 # WCS 1.0
 #===============================================================================
@@ -672,10 +681,11 @@ class WCS20GetCoverageTiledTestCase(eoxstest.RectifiedGridCoverageTestCase):
         params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=mosaic_MER_FRS_1P_RGB_reduced&format=%s" % quote ("image/tiff;tiled=YES")
         return (params, "kvp")
 
-class WCS20GetCoverageNetCDFInputTestCase(eoxstest.RectifiedGridCoverageTestCase):
-    def getRequest(self):
-        params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=MER_FRS_1PNPDE20060816_090929_000001972050_00222_23322_0058_uint16_reduced_compressed_netCDF&format=image/tiff"
-        return (params, "kvp")
+# TODO: Enable test once subdatasets are supported (see #123):
+#class WCS20GetCoverageNetCDFInputTestCase(eoxstest.RectifiedGridCoverageTestCase):
+#    def getRequest(self):
+#        params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=MER_FRS_1PNPDE20060816_090929_000001972050_00222_23322_0058_uint16_reduced_compressed_netCDF&format=image/tiff"
+#        return (params, "kvp")
 
 class WCS20GetCoverageJPEG2000InputTestCase(eoxstest.RectifiedGridCoverageTestCase):
     def getRequest(self):
@@ -961,14 +971,25 @@ class WCS20GetCoverageReferenceableDatasetImageCRSSubsetTestCase(eoxstest.WCS20G
 
 class WCS20GetCoverageReferenceableDatasetGeogCRSSubsetTestCase(eoxstest.WCS20GetCoverageReferenceableGridCoverageMultipartTestCase):
     def getRequest(self):
-        params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=ASA_WSM_1PNDPA20050331_075939_000000552036_00035_16121_0775&format=image/tiff&mediatype=multipart/mixed&subset=x,http://www.opengis.net/def/crs/EPSG/0/4326(19.1,20.1)&subset=y,http://www.opengis.net/def/crs/EPSG/0/4326(-35,-32.9)"
+        params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=ASA_WSM_1PNDPA20050331_075939_000000552036_00035_16121_0775&format=image/tiff&mediatype=multipart/mixed&subset=x,http://www.opengis.net/def/crs/EPSG/0/4326(18.0,20.0)&subset=y,http://www.opengis.net/def/crs/EPSG/0/4326(-34.5,-33.5)"
         return (params, "kvp")
-    
+
 class WCS20GetCoverageReferenceableDatasetGeogCRSSubsetExceedsExtentTestCase(eoxstest.WCS20GetCoverageReferenceableGridCoverageMultipartTestCase):
     def getRequest(self):
-        params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=ASA_WSM_1PNDPA20050331_075939_000000552036_00035_16121_0775&format=image/tiff&mediatype=multipart/mixed&subset=x,http://www.opengis.net/def/crs/EPSG/0/4326(14,16.4)&subset=y,http://www.opengis.net/def/crs/EPSG/0/4326(-39.5,-35.1)"
+        params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=ASA_WSM_1PNDPA20050331_075939_000000552036_00035_16121_0775&format=image/tiff&mediatype=multipart/mixed&subset=x,http://www.opengis.net/def/crs/EPSG/0/4326(18,23)&subset=y,http://www.opengis.net/def/crs/EPSG/0/4326(-35,-33)"
         return (params, "kvp")
 
+class WCS20GetCoverageReferenceableDatasetGeogCRSSubsetOutsideExtentTestCase(eoxstest.ExceptionTestCase):
+    def getRequest(self):
+        params = "service=wcs&version=2.0.0&request=GetCoverage&CoverageId=ASA_WSM_1PNDPA20050331_075939_000000552036_00035_16121_0775&format=image/tiff&mediatype=multipart/mixed&subset=x,http://www.opengis.net/def/crs/EPSG/0/4326(14.5,16.5)&subset=y,http://www.opengis.net/def/crs/EPSG/0/4326(-34.5,-33.5)"
+        return (params, "kvp")
+
+    def getExpectedHTTPStatus(self):
+        return 400
+    
+    def getExpectedExceptionCode(self):
+        return "InvalidParameterValue"
+
 #===============================================================================
 # WCS 2.0 - POST
 #===============================================================================
@@ -1226,6 +1247,12 @@ class WCS11PostGetCoverageMosaicTestCase(eoxstest.RectifiedGridCoverageMultipart
 # WMS
 #===============================================================================
 
+class WMS11GetCapabilitiesValidTestCase(eoxstest.OWSTestCase):
+    """This test shall retrieve a valid WMS 1.1 GetCapabilities response"""
+    def getRequest(self):
+        params = "service=WMS&version=1.1.1&request=GetCapabilities"
+        return (params, "kvp")
+
 class WMS13GetCapabilitiesValidTestCase(eoxstest.XMLTestCase):
     """This test shall retrieve a valid WMS 1.3 GetCapabilities response"""
     def getRequest(self):
@@ -1245,6 +1272,22 @@ class WMS13GetMapDatasetTestCase(eoxstest.WMS13GetMapTestCase):
     layers = ("mosaic_MER_FRS_1PNPDE20060822_092058_000001972050_00308_23408_0077_RGB_reduced",)
     bbox = (8.487755775451660, 32.195316643454134, 25.407486727461219, 46.249103546142578)
 
+class WMS13GetMapNoServiceParameterTestCase(eoxstest.RasterTestCase):
+    """This test shall retrieve a map while omitting the service parameter. """
+    def getRequest(self):
+        params = "version=1.3.0&request=GetMap&" \
+                 "layers=mosaic_MER_FRS_1P_RGB_reduced&styles=&crs=epsg:4326&" \
+                 "bbox=35,10,45,20&width=100&height=100&format=image/tiff"
+        return (params, "kvp")
+
+class WMS11GetMapMultipleDatasetsTestCase(eoxstest.WMS11GetMapTestCase):
+    """ Test a GetMap request with two datasets. """
+    layers = ("mosaic_MER_FRS_1PNPDE20060816_090929_000001972050_00222_23322_0058_RGB_reduced",
+              "mosaic_MER_FRS_1PNPDE20060830_100949_000001972050_00423_23523_0079_RGB_reduced",
+              )
+    width = 200
+    bbox = (-3.75, 32.19025, 28.29481, 46.268645)
+
 class WMS13GetMapMultipleDatasetsTestCase(eoxstest.WMS13GetMapTestCase):
     """ Test a GetMap request with two datasets. """
     layers = ("mosaic_MER_FRS_1PNPDE20060816_090929_000001972050_00222_23322_0058_RGB_reduced",
@@ -1262,6 +1305,7 @@ class WMS13GetMapMosaicTestCase(eoxstest.WMS13GetMapTestCase):
     """ Test a GetMap request with a stitched mosaic. """
     layers = ("mosaic_MER_FRS_1P_RGB_reduced",)
     bbox = (-3.75, 32.158895, 28.326165, 46.3)
+    width = 200
 
 class WMS13GetMapPNGDatasetTestCase(eoxstest.WMS13GetMapTestCase):
     """ Test a GetMap request with a dataset series. """
@@ -1327,38 +1371,37 @@ class WMS13GetMapReferenceableGridReprojectionTestCase(eoxstest.WMS13GetMapTestC
     height = 451
     swap_axes = False
 
-# TODO: Enable test cases once GEOSS exception is fixed
-#class WMS13GetMapDatasetSeriesTestCase(eoxstest.WMS13GetMapTestCase):
-#    """ Test a GetMap request with a dataset series. """
-#    layers = ("MER_FRS_1P_reduced",)
-#    width = 200
-#    bbox = (-3.75, 32.158895, 28.326165, 46.3)
-#
-#class WMS13GetMapDatasetSeriesTimePointTestCase(eoxstest.WMS13GetMapTestCase):
-#    layers = ("MER_FRS_1P_reduced",)
-#    width = 200
-#    bbox = (-3.75, 32.158895, 28.326165, 46.3)
-#    time = "2008-08-30T10:09:49Z"
-#    
-#class WMS13GetMapDatasetSeriesTimeIntervalTestCase(eoxstest.WMS13GetMapTestCase):
-#    layers = ("MER_FRS_1P_reduced",)
-#    width = 200
-#    bbox = (-3.75, 32.158895, 28.326165, 46.3)
-#    time = "2006-08-01T00:00:00Z/2006-08-16T23:59:59Z"
+class WMS13GetMapDatasetSeriesTestCase(eoxstest.WMS13GetMapTestCase):
+    """ Test a GetMap request with a dataset series. """
+    layers = ("MER_FRS_1P_RGB_reduced",)
+    width = 200
+    bbox = (-3.75, 32.158895, 28.326165, 46.3)
 
-class WMS13GetMapDatasetSeriesOutlinesTestCase(eoxstest.WMS13GetMapTestCase):
+class WMS13GetMapDatasetSeriesTimePointTestCase(eoxstest.WMS13GetMapTestCase):
+    layers = ("MER_FRS_1P_RGB_reduced",)
+    width = 200
+    bbox = (-3.75, 32.158895, 28.326165, 46.3)
+    time = "2006-08-30T10:09:49Z"
+
+class WMS13GetMapDatasetSeriesTimeIntervalTestCase(eoxstest.WMS13GetMapTestCase):
+    layers = ("MER_FRS_1P_RGB_reduced",)
+    width = 200
+    bbox = (-3.75, 32.158895, 28.326165, 46.3)
+    time = "2006-08-01T00:00:00Z/2006-08-22T23:59:59Z"
+
+class WMS13GetMapDatasetSeriesOutlinesTestCase(eoxstest.WMS13GetMapTransactionTestCase):
     requires_fixed_db = True
     layers = ("MER_FRS_1P_reduced_outlines",)
     width = 200
     bbox = (-3.75, 32.158895, 28.326165, 46.3)
 
-class WMS13GetMapRectifiedStitchedMosaicOutlinesTestCase(eoxstest.WMS13GetMapTestCase):
+class WMS13GetMapRectifiedStitchedMosaicOutlinesTestCase(eoxstest.WMS13GetMapTransactionTestCase):
     requires_fixed_db = True
     layers = ("mosaic_MER_FRS_1P_RGB_reduced_outlines",)
     width = 200
     bbox = (-3.75, 32.158895, 28.326165, 46.3)
 
-class WMS13GetMapRectifiedStitchedMosaicOutlinesWhiteTestCase(eoxstest.WMS13GetMapTestCase):
+class WMS13GetMapRectifiedStitchedMosaicOutlinesWhiteTestCase(eoxstest.WMS13GetMapTransactionTestCase):
     requires_fixed_db = True
     layers = ("mosaic_MER_FRS_1P_RGB_reduced_outlines",)
     width = 200
@@ -1384,7 +1427,7 @@ class WMS13GetMapReprojectedDatasetTestCase(eoxstest.WMS13GetMapTestCase):
     layers = ("MER_FRS_1PNPDE20060816_090929_000001972050_00222_23322_0058_uint16_reduced_compressed_reprojected",)
     bbox = (8.487755775451660, 32.195316643454134, 25.407486727461219, 46.249103546142578)
 
-class WMS13GetFeatureInfoTestCase(eoxstest.HTMLTestCase):
+class WMS13GetFeatureInfoTestCase(eoxstest.HTMLTransactionTestCase):
     """ Test a GetFeatureInfo on an outline layer. """
     requires_fixed_db = True
     def getRequest(self):
